Style Guide
-----------
All pull requests to the python source must follow `PEP 8 <https://www.python.org/dev/peps/pep-0008/>`_ and `PEP 257 <https://www.python.org/dev/peps/pep-0257/>`_ conventions.

In addition, all methods and functions must be in snake_case and not camelCase. This to keep things uniform across all modules. This should also help make identifying PyQt5 methods easier.


Issues
------

When opening new issues, if it is a bug, make sure to describe the bug in as detail as possible and some steps to reproduce the bug. If it's a feature or an enhancement, explain why it is needed.

Pull Requests
-------------

We follow `Github Flow <https://guides.github.com/introduction/flow/>`_ as our workflow when creating pull requests. It is a  neater and easier way to manage changes.
